commit 15a41eb543b7730ce879db8d89af1fa5d461ed77
Author: Cherian Mathew <c.mathew@bgbm.org>
Date:   Wed Feb 12 13:54:26 2014 +0000

    renaming ICdmApplicationConfiguration to ICdmApplicationDefaultConfiguration

diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/AlgaTerraActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/AlgaTerraActivator.java
index 5bfff852..7abbd50a 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/AlgaTerraActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/AlgaTerraActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.api.service.ITermService;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -183,7 +183,7 @@ public class AlgaTerraActivator {
 		bmImport.invoke(config);
 
 		if (doFacts && (config.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || config.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK) )   ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//make feature tree
 			makeTaxonFeatureTree(config, app);
@@ -203,7 +203,7 @@ public class AlgaTerraActivator {
 	 * @param config
 	 * @param app
 	 */
-	private void makeTaxonFeatureTree(AlgaTerraImportConfigurator config, ICdmApplicationConfiguration app) {
+	private void makeTaxonFeatureTree(AlgaTerraImportConfigurator config, ICdmApplicationDefaultConfiguration app) {
 		FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, config.getFeatureMap(), featureKeyList);
 		tree.setTitleCache("AlgaTerra Taxon Feature Tree", true);
 		
@@ -236,7 +236,7 @@ public class AlgaTerraActivator {
 	 * @param app
 	 * @param tree
 	 */
-	private void makeSpecimenFeatureTree(AlgaTerraImportConfigurator config, ICdmApplicationConfiguration app) {
+	private void makeSpecimenFeatureTree(AlgaTerraImportConfigurator config, ICdmApplicationDefaultConfiguration app) {
 		ITermService termService = app.getTermService();
 		FeatureTree specimenTree = FeatureTree.NewInstance(specimenFeatureTreeUuid);
 //		FeatureTree specimenTree = TreeCreator.flatTree(specimenFeatureTreeUuid, config.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/CampanulaceaeActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/CampanulaceaeActivator.java
index 3704acb4..4447d621 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/CampanulaceaeActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/CampanulaceaeActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.berlinModelImport.TreeCreator;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -173,7 +173,7 @@ public class CampanulaceaeActivator {
 		success &= bmImport.invoke(bmImportConfigurator);
 		
 		if (doFacts && (bmImportConfigurator.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || bmImportConfigurator.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK) )   ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//make feature tree
 			FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, bmImportConfigurator.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/EuroMedActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/EuroMedActivator.java
index 562717f5..7ad59afc 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/EuroMedActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/EuroMedActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -229,7 +229,7 @@ public class EuroMedActivator {
 		bmImport.invoke(config);
 		
 		if (doFacts && (config.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || config.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK)  )  ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//make feature tree
 			FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, config.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/IldisActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/IldisActivator.java
index 034bb294..f564bf00 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/IldisActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/IldisActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -155,7 +155,7 @@ public class IldisActivator {
 		success &= bmImport.invoke(bmImportConfigurator);
 		
 		if (doFacts && (bmImportConfigurator.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || bmImportConfigurator.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK) )   ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//make feature tree
 			FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, bmImportConfigurator.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTMooseActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTMooseActivator.java
index 9035f644..dd4b85ce 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTMooseActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTMooseActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -139,7 +139,7 @@ public class MTMooseActivator {
 		bmImport.invoke(bmImportConfigurator);
 
 		if (doFacts && (bmImportConfigurator.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || bmImportConfigurator.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK) )   ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//make feature tree
 			FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, bmImportConfigurator.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTStandardlisteActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTStandardlisteActivator.java
index 4cdb9734..1c2c853e 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTStandardlisteActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/berlinModelImport/MTStandardlisteActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -150,7 +150,7 @@ public class MTStandardlisteActivator {
 			bmImport.invoke(config);
 
 			if (doFacts && (config.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || config.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK) )   ){
-				ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+				ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 				
 				//make feature tree
 				FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, config.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/caryophyllales/CaryoActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/caryophyllales/CaryoActivator.java
index 7b967522..b5af4739 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/caryophyllales/CaryoActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/caryophyllales/CaryoActivator.java
@@ -13,7 +13,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.berlinModelImport.SourceBase;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -82,7 +82,7 @@ public class CaryoActivator extends SourceBase{
 		
 		//deduplicate
 		if (doDeduplicate){
-			ICdmApplicationConfiguration app = myImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = myImport.getCdmAppController();
 			int count = app.getAgentService().deduplicate(Person.class, null, null);
 			logger.warn("Deduplicated " + count + " persons.");
 //			count = app.getAgentService().deduplicate(Team.class, null, null);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/common/CdmDestinations.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/common/CdmDestinations.java
index 045bd762..5b332bc2 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/common/CdmDestinations.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/common/CdmDestinations.java
@@ -88,7 +88,7 @@ public class CdmDestinations {
 		DatabaseTypeEnum dbType = DatabaseTypeEnum.MySQL;
 		String cdmServer = "127.0.0.1";
 		String cdmDB = "dwca";
-		String cdmUserName = "edit";
+		String cdmUserName = "root";
 		return makeDestination(dbType, cdmServer, cdmDB, -1, cdmUserName, null);
 	}
 
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/common/TestActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/common/TestActivator.java
index 12f0583f..6b283324 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/common/TestActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/common/TestActivator.java
@@ -16,7 +16,7 @@ import org.apache.log4j.Logger;
 import org.springframework.core.io.ClassPathResource;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.common.monitor.DefaultProgressMonitor;
 import eu.etaxonomy.cdm.common.monitor.IProgressMonitor;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -64,7 +64,7 @@ public class TestActivator {
 
 		ICdmDataSource destination = cdmDestination;
 
-		CdmApplicationController app;
+		CdmApplicationDefaultController app;
 
 //		applicationEventMulticaster
 //		app = CdmIoApplicationController.NewInstance(destination, dbSchemaValidation);
@@ -75,8 +75,8 @@ public class TestActivator {
 //		ApplicationListener<?> listener = new AppImportApplicationListener();
 //		List<ApplicationListener> listeners = new ArrayList<ApplicationListener>();
 //		listeners.add(listener);
-//		app = CdmApplicationController.NewInstance(resource, destination, dbSchemaValidation, false, progressMonitor, listeners);
-		app = CdmApplicationController.NewInstance(resource, destination, dbSchemaValidation, false, progressMonitor);
+//		app = CdmApplicationDefaultController.NewInstance(resource, destination, dbSchemaValidation, false, progressMonitor, listeners);
+		app = CdmApplicationDefaultController.NewInstance(resource, destination, dbSchemaValidation, false, progressMonitor);
 
 
 
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/cyprus/CyprusActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/cyprus/CyprusActivator.java
index cb1255ee..c529b79f 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/cyprus/CyprusActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/cyprus/CyprusActivator.java
@@ -15,7 +15,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.api.service.ITermService;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -99,7 +99,7 @@ public class CyprusActivator {
 		
 		//deduplicate
 		if (doDeduplicate){
-			ICdmApplicationConfiguration app = myImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = myImport.getCdmAppController();
 			int count = app.getAgentService().deduplicate(Person.class, null, null);
 			logger.warn("Deduplicated " + count + " persons.");
 //			count = app.getAgentService().deduplicate(Team.class, null, null);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/dwca/DwcaImportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/dwca/DwcaImportActivator.java
index ea5d22d1..2d5677a7 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/dwca/DwcaImportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/dwca/DwcaImportActivator.java
@@ -14,7 +14,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -122,7 +122,7 @@ public class DwcaImportActivator {
 		
 		//deduplicate
 		if (doDeduplicate){
-			ICdmApplicationConfiguration app = myImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = myImport.getCdmAppController();
 			int count = app.getAgentService().deduplicate(Person.class, null, null);
 			logger.warn("Deduplicated " + count + " persons.");
 //			count = app.getAgentService().deduplicate(Team.class, null, null);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/globis/GlobisActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/globis/GlobisActivator.java
index add6088c..a62988e1 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/globis/GlobisActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/globis/GlobisActivator.java
@@ -14,7 +14,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.common.CdmImportSources;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -131,7 +131,7 @@ public class GlobisActivator {
 		globisImport.invoke(config);
 		
 		if (config.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || config.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK)    ){
-			ICdmApplicationConfiguration app = globisImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = globisImport.getCdmAppController();
 			ISourceable obj = app.getCommonService().getSourcedObjectByIdInSource(ZoologicalName.class, "1000027", null);
 			logger.info(obj);
 			
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/i4life/col/ColDwcaImportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/i4life/col/ColDwcaImportActivator.java
index 9cc15d7b..27bb1aa3 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/i4life/col/ColDwcaImportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/i4life/col/ColDwcaImportActivator.java
@@ -14,7 +14,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -54,7 +54,7 @@ public class ColDwcaImportActivator {
 	
 	//check - import
 	static final CHECK check = CHECK.IMPORT_WITHOUT_CHECK;
-	static int partitionSize = 1000;
+	static int partitionSize = 5000;
 	
 	//config
 	static DatasetUse datasetUse = DatasetUse.ORIGINAL_SOURCE;
@@ -110,7 +110,7 @@ public class ColDwcaImportActivator {
 		
 		//deduplicate
 		if (doDeduplicate){
-			ICdmApplicationConfiguration app = myImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = myImport.getCdmAppController();
 			int count = app.getAgentService().deduplicate(Person.class, null, null);
 			logger.warn("Deduplicated " + count + " persons.");
 //			count = app.getAgentService().deduplicate(Team.class, null, null);
@@ -137,7 +137,7 @@ public class ColDwcaImportActivator {
 	
 	//CoL
 	public static URI dwca_col_All() {
-		URI sourceUrl = URI.create("file:////Pesiimport3/col/col_20Nov2012.zip");
+		URI sourceUrl = URI.create("file:///data/dwca/xylariaceae/added.zip");
 		return sourceUrl;
 	}
 
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/images/AbstractImageImporter.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/images/AbstractImageImporter.java
index c77f9805..09b33651 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/images/AbstractImageImporter.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/images/AbstractImageImporter.java
@@ -12,7 +12,7 @@ package eu.etaxonomy.cdm.app.images;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.api.service.IAgentService;
 import eu.etaxonomy.cdm.api.service.ICommonService;
 import eu.etaxonomy.cdm.api.service.IDescriptionService;
@@ -31,9 +31,9 @@ import eu.etaxonomy.cdm.io.common.ICdmIO;
 public abstract class AbstractImageImporter extends CdmIoBase<ImageImportState> implements ICdmIO<ImageImportState> {
 	private static final Logger logger = Logger.getLogger(AbstractImageImporter.class);
 	
-	protected CdmApplicationController appCtr;
+	protected CdmApplicationDefaultController appCtr;
 	
-	protected CdmApplicationController cdmApp;
+	protected CdmApplicationDefaultController cdmApp;
 	protected ITaxonService taxonService;
 	protected IClassificationService classificationService;
 	//TODO:
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbExportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbExportActivator.java
index 2611b69c..638b2535 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbExportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbExportActivator.java
@@ -13,7 +13,7 @@ import java.net.URI;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.util.TestDatabase;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -78,10 +78,10 @@ public class JaxbExportActivator {
 	
 
 	
-	private CdmApplicationController initDb(ICdmDataSource db) {
+	private CdmApplicationDefaultController initDb(ICdmDataSource db) {
 
 		// Init source DB
-		CdmApplicationController appCtrInit = null;
+		CdmApplicationDefaultController appCtrInit = null;
 
 		appCtrInit = TestDatabase.initDb(db, DbSchemaValidation.VALIDATE, false);
 
@@ -90,7 +90,7 @@ public class JaxbExportActivator {
 
 	
 	// Load test data to DB
-	private void loadTestData(CdmApplicationController appCtrInit) {
+	private void loadTestData(CdmApplicationDefaultController appCtrInit) {
 		TestDatabase.loadTestData("", appCtrInit);
 	}
 
@@ -104,7 +104,7 @@ public class JaxbExportActivator {
 		ICdmDataSource source = CdmDestinations.chooseDestination(args) != null ? CdmDestinations.chooseDestination(args) : cdmSource;
 		String file = chooseFile(args);
 		URI uri = URI.create(file);
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 		appCtr = sc.initDb(source);
 				
 		sc.invokeExport(source, uri);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbImportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbImportActivator.java
index 744c900b..86be7397 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbImportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/jaxb/JaxbImportActivator.java
@@ -14,7 +14,7 @@ import java.net.URISyntaxException;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.util.TestDatabase;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -38,7 +38,7 @@ public class JaxbImportActivator {
 	private static String importFileNameString = 
 		//"C:\\workspace\\cdmlib_2.2\\cdmlib-io\\src\\test\\resources\\eu\\etaxonomy\\cdm\\io\\jaxb\\export_test_app_import.xml";
 //		"file:/C:/export_test_app_import.xml";
-	"file:/C:/localCopy/Data/kr�hen/201206141338-jaxb_export-cdm.xml";
+	"file:/C:/localCopy/Data/kr�hen/201206141338-jaxb_export-cdm.xml";
 	
 
 	/** NUMBER_ROWS_TO_RETRIEVE = 0 is the default case to retrieve all rows.
@@ -95,10 +95,10 @@ public class JaxbImportActivator {
 	}
 
 	
-	private CdmApplicationController initDb(ICdmDataSource db) {
+	private CdmApplicationDefaultController initDb(ICdmDataSource db) {
 
 		// Init source DB
-		CdmApplicationController appCtrInit = null;
+		CdmApplicationDefaultController appCtrInit = null;
 
 		appCtrInit = TestDatabase.initDb(db, DbSchemaValidation.CREATE, false);
 
@@ -107,7 +107,7 @@ public class JaxbImportActivator {
 
 	
 	// Load test data to DB
-	private void loadTestData(CdmApplicationController appCtrInit) {
+	private void loadTestData(CdmApplicationDefaultController appCtrInit) {
 
 		TestDatabase.loadTestData("", appCtrInit);
 	}
@@ -121,7 +121,7 @@ public class JaxbImportActivator {
 		JaxbImportActivator jia = new JaxbImportActivator();
 		ICdmDataSource destination = CdmDestinations.chooseDestination(args) != null ? CdmDestinations.chooseDestination(args) : cdmDestination;
 		String file = chooseFile(args)!= null ? chooseFile(args) : importFileNameString;
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 //		appCtr = jia.initDb(destination);
 				
 		jia.invokeImport(file, destination);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/pilotOutputHtml/SimpleDescriptionOutput.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/pilotOutputHtml/SimpleDescriptionOutput.java
index 9b1fac28..2bf05b9f 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/pilotOutputHtml/SimpleDescriptionOutput.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/pilotOutputHtml/SimpleDescriptionOutput.java
@@ -115,7 +115,7 @@ public class SimpleDescriptionOutput {
 
 		SimpleDescriptionOutput sdo = new SimpleDescriptionOutput();
 
-//		CdmApplicationController appCtr = null;
+//		CdmApplicationDefaultController appCtr = null;
 //		appCtr = sc.initDb(sourceDb);
 //		sc.loadTestData(appCtr);
 		
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/proibiosphere/TaxonXImportLauncher.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/proibiosphere/TaxonXImportLauncher.java
index 044e8bac..158a4626 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/proibiosphere/TaxonXImportLauncher.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/proibiosphere/TaxonXImportLauncher.java
@@ -121,7 +121,7 @@ public class TaxonXImportLauncher {
                     log.info("End import from SpecimenData ("+ source.toString() + ")...");
 
                     //          //deduplicate
-                    //            ICdmApplicationConfiguration app = taxonImport.getCdmAppController();
+                    //            ICdmApplicationDefaultConfiguration app = taxonImport.getCdmAppController();
                     //            int count = app.getAgentService().deduplicate(Person.class, null, null);
                     //            logger.warn("Deduplicated " + count + " persons.");
                     //            count = app.getReferenceService().deduplicate(Reference.class, null, null);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/references/EndNoteImportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/references/EndNoteImportActivator.java
index 145c348f..3db1e261 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/references/EndNoteImportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/references/EndNoteImportActivator.java
@@ -5,7 +5,7 @@ import java.net.URISyntaxException;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.util.TestDatabase;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -72,10 +72,10 @@ public class EndNoteImportActivator {
 	}
 
 	
-	private CdmApplicationController initDb(ICdmDataSource db) {
+	private CdmApplicationDefaultController initDb(ICdmDataSource db) {
 
 		// Init source DB
-		CdmApplicationController appCtrInit = null;
+		CdmApplicationDefaultController appCtrInit = null;
 
 		appCtrInit = TestDatabase.initDb(db, DbSchemaValidation.VALIDATE, true);
 
@@ -84,7 +84,7 @@ public class EndNoteImportActivator {
 
 	
 	// Load test data to DB
-	private void loadTestData(CdmApplicationController appCtrInit) {
+	private void loadTestData(CdmApplicationDefaultController appCtrInit) {
 
 		TestDatabase.loadTestData("", appCtrInit);
 	}
@@ -98,7 +98,7 @@ public class EndNoteImportActivator {
 		EndNoteImportActivator sc = new EndNoteImportActivator();
 		ICdmDataSource destination = CdmDestinations.chooseDestination(args) != null ? CdmDestinations.chooseDestination(args) : cdmDestination;
 		String file = chooseFile(args)!= null ? chooseFile(args) : importFileNameString;
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 		appCtr = sc.initDb(destination);
 		//sc.loadTestData(appCtr);
 				
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDExportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDExportActivator.java
index e6b7e68b..cbad41c1 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDExportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDExportActivator.java
@@ -91,7 +91,7 @@ public class SDDExportActivator {
        CdmPersistentDataSource.save(dataSourceName, dataSource);
        try {
            loadedDataSource = CdmPersistentDataSource.NewInstance(dataSourceName);
-//			CdmApplicationController.NewInstance(loadedDataSource, DbSchemaValidation.CREATE);
+//			CdmApplicationDefaultController.NewInstance(loadedDataSource, DbSchemaValidation.CREATE);
            NomenclaturalCode loadedCode = loadedDataSource.getNomenclaturalCode();
 
            Assert.assertEquals(NomenclaturalCode.ICNAFP, loadedCode);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDImportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDImportActivator.java
index b99630dd..9dfded0e 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDImportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/SDDImportActivator.java
@@ -84,7 +84,7 @@ public class SDDImportActivator {
        CdmPersistentDataSource.save(dataSourceName, dataSource);
        try {
            loadedDataSource = CdmPersistentDataSource.NewInstance(dataSourceName);
-//			CdmApplicationController.NewInstance(loadedDataSource, DbSchemaValidation.CREATE);
+//			CdmApplicationDefaultController.NewInstance(loadedDataSource, DbSchemaValidation.CREATE);
            NomenclaturalCode loadedCode = loadedDataSource.getNomenclaturalCode();
 
            Assert.assertEquals(NomenclaturalCode.ICNAFP, loadedCode);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/ViolaExportActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/ViolaExportActivator.java
index ba24dec7..9ef98587 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/ViolaExportActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/sdd/ViolaExportActivator.java
@@ -112,7 +112,7 @@ public class ViolaExportActivator {
 
 		ViolaExportActivator vea = new ViolaExportActivator();
 
-//		CdmApplicationController appCtr = null;
+//		CdmApplicationDefaultController appCtr = null;
 //		appCtr = sc.initDb(sourceDb);
 //		sc.loadTestData(appCtr);
 		
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/synthesysImport/SynthesysCacheActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/synthesysImport/SynthesysCacheActivator.java
index c996b26a..c88d1094 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/synthesysImport/SynthesysCacheActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/synthesysImport/SynthesysCacheActivator.java
@@ -21,7 +21,7 @@ import org.apache.log4j.Logger;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.api.service.pager.Pager;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.common.CdmImportSources;
@@ -137,10 +137,10 @@ public class SynthesysCacheActivator {
 	public boolean invoke(){
 		boolean result = true;
 		boolean withCdm = true;
-		CdmApplicationController app = null;
+		CdmApplicationDefaultController app = null;
 		TransactionStatus tx = null;
 
-		app = CdmApplicationController.NewInstance(desitination, hbm2dll);
+		app = CdmApplicationDefaultController.NewInstance(desitination, hbm2dll);
 		
 		tx = app.startTransaction();
 		try {
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestDatabase.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestDatabase.java
index 224a69aa..00d03ac6 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestDatabase.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestDatabase.java
@@ -13,7 +13,7 @@ import java.util.List;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.common.AccountStore;
 import eu.etaxonomy.cdm.database.CdmDataSource;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -71,18 +71,18 @@ public class TestDatabase {
 		return datasource;
 	}
 	
-    public static CdmApplicationController 
+    public static CdmApplicationDefaultController 
     initDb(ICdmDataSource db, DbSchemaValidation dbSchemaValidation, boolean omitTermLoading) {
     	
 		logger.info("Initializing database '" + db.getName() + "'");
 		
-		CdmApplicationController appCtrInit = null;
-		appCtrInit = CdmApplicationController.NewInstance(db, dbSchemaValidation, omitTermLoading);
+		CdmApplicationDefaultController appCtrInit = null;
+		appCtrInit = CdmApplicationDefaultController.NewInstance(db, dbSchemaValidation, omitTermLoading);
 		
 		return appCtrInit;
     }
     
-	public static void loadTestData(String dbname, CdmApplicationController appCtr) {
+	public static void loadTestData(String dbname, CdmApplicationDefaultController appCtr) {
     	
 		logger.info("Loading test data into " + dbname);
 		
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/vibrant/EuroMedActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/vibrant/EuroMedActivator.java
index 2f74b97d..f4eea270 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/vibrant/EuroMedActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/vibrant/EuroMedActivator.java
@@ -16,7 +16,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.berlinModelImport.BerlinModelSources;
 import eu.etaxonomy.cdm.app.berlinModelImport.TreeCreator;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
@@ -231,7 +231,7 @@ public class EuroMedActivator {
 		bmImport.invoke(config);
 		
 		if (doFacts && config.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || config.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK)    ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//make feature tree
 			FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, config.getFeatureMap(), featureKeyList);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/viennaImport/ViennaActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/viennaImport/ViennaActivator.java
index e3e865cc..24de542f 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/viennaImport/ViennaActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/viennaImport/ViennaActivator.java
@@ -17,7 +17,7 @@ import java.util.List;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.common.AccountStore;
@@ -63,14 +63,14 @@ public class ViennaActivator {
 		boolean result = true;
 		boolean withCdm = false;
 		berlinModelSource.setQuery("SELECT * FROM vienna"); // WHERE ID1 <> 1
-		CdmApplicationController app = null;
+		CdmApplicationDefaultController app = null;
 		
 		
 		try {
 			if (withCdm){
-				app = CdmApplicationController.NewInstance(CdmDestinations.localH2());
+				app = CdmApplicationDefaultController.NewInstance(CdmDestinations.localH2());
 			}else{
-				//app = CdmApplicationController.NewInstance(DbSchemaValidation.VALIDATE);
+				//app = CdmApplicationDefaultController.NewInstance(DbSchemaValidation.VALIDATE);
 			}
 		} catch (Exception e1) {
 			e1.printStackTrace();
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/CichorieaeActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/CichorieaeActivator.java
index 96c422c4..97d6385e 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/CichorieaeActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/CichorieaeActivator.java
@@ -16,7 +16,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.berlinModelImport.BerlinModelSources;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.berlinModelImport.TreeCreator;
@@ -218,7 +218,7 @@ public class CichorieaeActivator {
 		success &= bmImport.invoke(bmImportConfigurator);
 		
 		if (doFacts && (bmImportConfigurator.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || bmImportConfigurator.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK) )   ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			ISourceable obj = app.getCommonService().getSourcedObjectByIdInSource(ZoologicalName.class, "1000027", null);
 			logger.info(obj);
 			
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/TaraxacumActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/TaraxacumActivator.java
index 685c69e4..7b6d90f6 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/TaraxacumActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/cichorieae/TaraxacumActivator.java
@@ -16,7 +16,7 @@ import java.util.UUID;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.berlinModelImport.BerlinModelSources;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -174,7 +174,7 @@ public class TaraxacumActivator {
 		success &= bmImport.invoke(bmImportConfigurator);
 		
 		if (bmImportConfigurator.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || bmImportConfigurator.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK)    ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			TransactionStatus tx = app.startTransaction();
 			//make feature tree
 //			FeatureTree tree = TreeCreator.flatTree(featureTreeUuid, bmImportConfigurator.getFeatureMap(), featureKeyList);
@@ -193,7 +193,7 @@ public class TaraxacumActivator {
 	}
 	
 	
-	public boolean mergeIntoCichorieae(ICdmApplicationConfiguration app){
+	public boolean mergeIntoCichorieae(ICdmApplicationDefaultConfiguration app){
 		boolean success = true;
 	//	String taraxTaraxacumUuidStr = "9a7bced0-fa1a-432e-9cca-57b62219cde6";
 		String taraxTaraxacumUuidStr = "b86f1156-091c-494d-a9c9-c84d71058f98";
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraActivator.java
index 695c781d..cb2d0a37 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraActivator.java
@@ -14,7 +14,7 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.berlinModelImport.BerlinModelSources;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.berlinModelImport.TreeCreator;
@@ -183,7 +183,7 @@ public class DipteraActivator {
 		success &= bmImport.invoke(bmImportConfigurator);
 		
 		if (bmImportConfigurator.getCheck().equals(CHECK.CHECK_AND_IMPORT)  || bmImportConfigurator.getCheck().equals(CHECK.IMPORT_WITHOUT_CHECK)    ){
-			ICdmApplicationConfiguration app = bmImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = bmImport.getCdmAppController();
 			
 			//parse distributions
 			if (doDistributionParser){
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraCollectionImport.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraCollectionImport.java
index 74c3d0bc..dc55be22 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraCollectionImport.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraCollectionImport.java
@@ -23,7 +23,7 @@ import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
 import au.com.bytecode.opencsv.CSVReader;
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.common.CdmUtils;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
@@ -47,7 +47,7 @@ public class DipteraCollectionImport {
 	
 
 	public boolean invoke(ICdmDataSource dataSource) {
-		CdmApplicationController cdmApp = CdmApplicationController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
+		CdmApplicationDefaultController cdmApp = CdmApplicationDefaultController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
 			
 		//create collections
 		TransactionStatus tx = cdmApp.startTransaction();
@@ -66,7 +66,7 @@ public class DipteraCollectionImport {
 	 * @param cdmApp
 	 * @param colletionMap 
 	 */
-	private void addCollectionsToSpecimen(CdmApplicationController cdmApp, Map<String, Collection> colletionMap) {
+	private void addCollectionsToSpecimen(CdmApplicationDefaultController cdmApp, Map<String, Collection> colletionMap) {
 		List<SpecimenOrObservationBase> specimens = (cdmApp.getOccurrenceService().list(DerivedUnit.class, null, null, null, null));
 		for (SpecimenOrObservationBase<?> specOrObservBase : specimens){
 			if (specOrObservBase.getRecordBasis().isPreservedSpecimen()){
@@ -186,7 +186,7 @@ public class DipteraCollectionImport {
 	/**
 	 * @param cdmApp
 	 */
-	private Map<String, Collection> createCollections(CdmApplicationController cdmApp) {
+	private Map<String, Collection> createCollections(CdmApplicationDefaultController cdmApp) {
 		Map<String, Collection> collectionMap = new HashMap<String, Collection>(); 
 		List<String[]> lines = getLines();
 		for (String[] line:lines){
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraDistributionParser.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraDistributionParser.java
index 7ef1ad7c..4fb1c2eb 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraDistributionParser.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraDistributionParser.java
@@ -26,8 +26,8 @@ import java.util.regex.Pattern;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -58,7 +58,7 @@ public class DipteraDistributionParser {
 	final static String epiSplitter = "(\\s+|\\[|\\]|\\(|\\))"; //( ' '+| '(' | ')'| '[' | ']' )
 	static Pattern pattern = null;
 	
-	protected void doDistribution(ICdmApplicationConfiguration app){
+	protected void doDistribution(ICdmApplicationDefaultConfiguration app){
 		pattern = Pattern.compile(epiSplitter); 
 	    TransactionStatus txStatus = app.startTransaction();
 		List<TaxonBase> taxa = app.getTaxonService().list(null, null, null, null, null);
@@ -415,9 +415,9 @@ public class DipteraDistributionParser {
 	 * @param args
 	 */
 	public static void main(String[] args) {
-		CdmApplicationController app = null;
+		CdmApplicationDefaultController app = null;
 		DbSchemaValidation val = DbSchemaValidation.UPDATE;
-		app = CdmApplicationController.NewInstance(cdmDestination, val);
+		app = CdmApplicationDefaultController.NewInstance(cdmDestination, val);
 		
 		DipteraDistributionParser dipDist = new DipteraDistributionParser();
 		if (app != null){
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraPostImportUpdater.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraPostImportUpdater.java
index 8ecce277..c55ce809 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraPostImportUpdater.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/diptera/DipteraPostImportUpdater.java
@@ -19,7 +19,7 @@ import java.util.Set;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.api.service.INameService;
 import eu.etaxonomy.cdm.api.service.pager.Pager;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
@@ -60,7 +60,7 @@ public class DipteraPostImportUpdater {
 		try{
 			logger.warn("start updating citations");
 			boolean result = true;
-			CdmApplicationController cdmApp = CdmApplicationController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
+			CdmApplicationDefaultController cdmApp = CdmApplicationDefaultController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
 			Set<DescriptionElementBase> citationsToSave = new HashSet<DescriptionElementBase>();
 			TransactionStatus tx = cdmApp.startTransaction();
 
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaeActivator.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaeActivator.java
index b9d6fe3c..6b3c4ba9 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaeActivator.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaeActivator.java
@@ -16,8 +16,8 @@ import java.util.UUID;
 
 import org.apache.log4j.Logger;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
-import eu.etaxonomy.cdm.api.application.ICdmApplicationConfiguration;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
+import eu.etaxonomy.cdm.api.application.ICdmApplicationDefaultConfiguration;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.app.images.ImageImportConfigurator;
 import eu.etaxonomy.cdm.app.tcs.TcsSources;
@@ -121,7 +121,7 @@ public class PalmaeActivator {
 			
 			//make feature tree
 			logger.info("Make feature tree");
-			ICdmApplicationConfiguration app = tcsImport.getCdmAppController();
+			ICdmApplicationDefaultConfiguration app = tcsImport.getCdmAppController();
 			
 			FeatureTree tree = getFeatureTree();
 			app.getFeatureTreeService().saveOrUpdate(tree);
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaePostImportUpdater.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaePostImportUpdater.java
index bb902eed..7cdd7f6e 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaePostImportUpdater.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/PalmaePostImportUpdater.java
@@ -17,7 +17,7 @@ import java.util.UUID;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.app.common.CdmDestinations;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
@@ -53,7 +53,7 @@ public class PalmaePostImportUpdater {
 		try{
 			int count = 0;
 			UUID featureTreeUuid = PalmaeActivator.featureTreeUuid;
-			CdmApplicationController cdmApp = CdmApplicationController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
+			CdmApplicationDefaultController cdmApp = CdmApplicationDefaultController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
 			
 			TransactionStatus tx = cdmApp.startTransaction();
 			
@@ -95,7 +95,7 @@ public class PalmaePostImportUpdater {
 	public boolean updateNameUsage(ICdmDataSource dataSource) {
 		try{
 			boolean result = true;
-			CdmApplicationController cdmApp = CdmApplicationController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
+			CdmApplicationDefaultController cdmApp = CdmApplicationDefaultController.NewInstance(dataSource, DbSchemaValidation.VALIDATE);
 
 			TransactionStatus tx = cdmApp.startTransaction();
 
diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/UseImport.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/UseImport.java
index bc18eeb6..b334e202 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/UseImport.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/wp6/palmae/UseImport.java
@@ -29,7 +29,7 @@ import org.apache.poi.hssf.usermodel.HSSFSheet;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
 import eu.etaxonomy.cdm.api.service.IDescriptionService;
 import eu.etaxonomy.cdm.api.service.IFeatureTreeService;
@@ -105,7 +105,7 @@ public class UseImport {
 	public boolean importFromExcelSS(String xlsPath) {
 		boolean success = true;
 		
-		CdmApplicationController applicationController = CdmApplicationController.NewInstance(dataSource());
+		CdmApplicationDefaultController applicationController = CdmApplicationDefaultController.NewInstance(dataSource());
 		ConversationHolder conversation = applicationController.NewConversation();
 		conversation.startTransaction();
 		
@@ -273,7 +273,7 @@ public class UseImport {
 		InputStream inputStream = null;
 		
 		
-		CdmApplicationController applicationController = CdmApplicationController.NewInstance(dataSource());
+		CdmApplicationDefaultController applicationController = CdmApplicationDefaultController.NewInstance(dataSource());
 		ConversationHolder conversation = applicationController.NewConversation();
 		conversation.startTransaction();
 		
@@ -497,7 +497,7 @@ public class UseImport {
 		//String xslPathString = "C://workspace//terms.xls";
 		String xslPathString = "//Users//alextheys//Projects//CDM_Trunk//Palm_Use_Data_Extension//CDMLib-apps//cdmlib-apps//UseImport//src//main//resources//terms.xls";
 		
-		CdmApplicationController applicationController = CdmApplicationController.NewInstance(dataSource());
+		CdmApplicationDefaultController applicationController = CdmApplicationDefaultController.NewInstance(dataSource());
 		ConversationHolder conversation = applicationController.NewConversation();
 		conversation.startTransaction();
 		
@@ -707,7 +707,7 @@ public class UseImport {
 	
 	private boolean setupNecessaryItems() {
 		boolean success = false;
-		CdmApplicationController applicationController = CdmApplicationController.NewInstance(dataSource());
+		CdmApplicationDefaultController applicationController = CdmApplicationDefaultController.NewInstance(dataSource());
 		ConversationHolder conversation = applicationController.NewConversation();
 		
 		

diff --git a/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestTransaction.java b/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestTransaction.java
index a12ffb46..f9ea29ac 100644
--- a/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestTransaction.java
+++ b/app-import/src/main/java/eu/etaxonomy/cdm/app/util/TestTransaction.java
@@ -12,7 +12,7 @@ import java.util.UUID;
 import org.apache.log4j.Logger;
 import org.springframework.transaction.TransactionStatus;
 
-import eu.etaxonomy.cdm.api.application.CdmApplicationController;
+import eu.etaxonomy.cdm.api.application.CdmApplicationDefaultController;
 import eu.etaxonomy.cdm.database.DbSchemaValidation;
 import eu.etaxonomy.cdm.database.ICdmDataSource;
 import eu.etaxonomy.cdm.model.agent.AgentBase;
@@ -51,11 +51,11 @@ public class TestTransaction {
      */    
 	private void modifyDisjunctObjects() {
 		
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 		logger.info("Test modifying disjunct objects");
 
 		try {
-			appCtr = CdmApplicationController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
+			appCtr = CdmApplicationDefaultController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
 
 		} catch (Exception e) {
 			logger.error("Error creating application controller");
@@ -129,11 +129,11 @@ public class TestTransaction {
      */    
 	private void modifySharedObjects() {
 		
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 		logger.info("Test modifying shared objects");
 
 		try {
-			appCtr = CdmApplicationController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
+			appCtr = CdmApplicationDefaultController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
 
 		} catch (Exception e) {
 			logger.error("Error creating application controller");
@@ -199,11 +199,11 @@ public class TestTransaction {
 
 	private void checkTransactionFacets() {
 		
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 		logger.info("Test checking transaction facets");
 		
 		try {
-			appCtr = CdmApplicationController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
+			appCtr = CdmApplicationDefaultController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
 
 		} catch (Exception e) {
 			logger.error("Error creating application controller");
@@ -216,7 +216,7 @@ public class TestTransaction {
 			
 	    	TransactionStatus txStatOne = appCtr.startTransaction();
 	    	appCtr.commitTransaction(txStatOne);
 	    	// set CdmApplicationController = debug in log4j.properties to see the transaction properties
 	    	appCtr.close();
 			logger.info("End test ask session for objects"); 
 			
@@ -228,11 +228,11 @@ public class TestTransaction {
 		
 	private void askSessionForObjects() {
 		
-		CdmApplicationController appCtr = null;
+		CdmApplicationDefaultController appCtr = null;
 		logger.info("Test asking session for objects");
 
 		try {
-			appCtr = CdmApplicationController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
+			appCtr = CdmApplicationDefaultController.NewInstance(db, DbSchemaValidation.VALIDATE, true);
 
 		} catch (Exception e) {
 			logger.error("Error creating application controller");
@@ -299,7 +299,7 @@ public class TestTransaction {
 		
     	/* Init DB */
 		// initDb(ICdmDataSource db, DbSchemaValidation dbSchemaValidation, boolean omitTermLoading)
-		CdmApplicationController appCtrInit = TestDatabase.initDb(db, DbSchemaValidation.CREATE, false);
+		CdmApplicationDefaultController appCtrInit = TestDatabase.initDb(db, DbSchemaValidation.CREATE, false);
 
 		/* Load test data into DB */
 //    	TestDatabase.loadTestData(dbName, appCtrInit);
@@ -216,7 +216,7 @@ public class TestTransaction {
 	    	TransactionStatus txStatOne = appCtr.startTransaction();
 	    	appCtr.commitTransaction(txStatOne);
-	    	// set CdmApplicationController = debug in log4j.properties to see the transaction properties
+	    	// set CdmApplicationDefaultController = debug in log4j.properties to see the transaction properties
 	    	appCtr.close();
 			logger.info("End test ask session for objects"); 